==> session_reminder-1.0.1.tar.gz: session_reminder/src/Form/ModalForm.php <==
<?php

namespace Drupal\session_reminder\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\session_reminder\Helper\SessionHelper;
use Drupal\session_reminder\Helper\SessionReminderHelper;
use Symfony\Component\HttpFoundation\Session\SessionInterface;

/**
 * Provides a Form for managing a modal form with a refresh button and countdown.
 */
class ModalForm extends FormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'sr__modal_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {

    if (!SessionReminderHelper::userEnabled()){
      return $form;
    }

    $config = \Drupal::config('session_reminder.settings');
    $colorBtnBg = $config->get('color_btn_bg');
    $colorBtnText = $config->get('color_btn_text');
    $colorModalTitle = $config->get('color_modal_title');
    $colorModalBg = $config->get('color_modal_bg');
    $colorModalText = $config->get('color_modal_text');
    $modalBorderRadius = $config->get('modal_border_radius');

    $form['sr__modal_form']['cancel'] = [
      '#type' => 'markup',
      '#markup' => '<a class="sr--modal-form--cancel">X</a>'
    ];

    $form['sr__modal_form']['title'] = [
      '#type' => 'container',
      '#markup' => '<h2 class="sr--modal-form--title">'.$this->t('Session expiring').'</h2>',
      '#attributes' => [
        'style' => "color: $colorModalTitle;"
      ]
    ];

    $form['sr__modal_form']['description'] = [
      '#type' => 'container',
      '#markup' => '<p class="sr--modal-form--description">'. $this->t("Your session will expire in @sec seconds",['@sec'=>0]).'</p>',
      '#attributes' => [
        'style' => "color: $colorModalText;"
      ]
    ];

    $form['sr__modal_form']['actions'] = ['#type' => 'actions'];

    $form['sr__modal_form']['actions']['submit'] = [
      '#type' => 'submit',
      '#button_type' => 'primary',
      '#value' => $this->t('Extend Session'),
      '#attributes' => [
        'class' => ['sr--modal-form--refresh-btn'],
        'style' => "background-color: $colorBtnBg; color: $colorBtnText;"
      ]
    ];

    $form['sr__modal_form']['actions']['close'] = [
      '#type' => 'button',
      '#button_type' => 'primary',
      '#value' => $this->t('Close'),
      '#attributes' => [
        'class' => ['sr--modal-form--close-btn']
      ],
      '#submit' => ['::reloadPage']
    ];

    $style = 'background-color: ' . $colorModalBg . ';';
    $style .= 'border-radius: ' . $modalBorderRadius . 'px;';
    $form['#attributes']['id'][] = 'sr--modal-form';
    $form['#attributes']['class'][] = 'sr--modal-form';
    $form['#attributes']['style'] = $style;
    $form['#cache'] = ['max-age' => 0];
    $form['#attached']['library'][] = 'session_reminder/modal-form-library';
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    //Chiamo servizio che estende sessione
    $request = \Drupal::request();
    /** @var SessionInterface $session */
    $sessionCookieName = $request->getSession()->getName();

    if (SessionReminderHelper::userEnabled() && !empty($sessionCookieName) && isset($_COOKIE[$sessionCookieName])){
      $sessionCookieValue = $_COOKIE[$sessionCookieName];
      unset($_COOKIE[$sessionCookieName]);
      $addSeconds = ini_get('session.cookie_lifetime');
      $newExpiringDatetime = time()+$addSeconds;
      setcookie(
        $sessionCookieName,
        $sessionCookieValue,
        $newExpiringDatetime,
        ini_get('session.cookie_path'),
        ini_get('session.cookie_domain'),
        ini_get('session.cookie_httponly'),
        ini_get('session.cookie_secure')
      );
      SessionHelper::setExpTimestamp($newExpiringDatetime);
    }
  }


  /**
   * Manage the reloadPage, used in Close Button
   *
   * @param array $form
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *
   * @return void
   */
  public function reloadPage(array &$form, FormStateInterface $form_state) {
    // Refresh current page
    $form_state->setRedirect('<current>');
  }

}

==> session_reminder-1.0.2.tar.gz: session_reminder/src/Form/ModalForm.php <==
<?php

namespace Drupal\session_reminder\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\session_reminder\Helper\SessionHelper;
use Drupal\session_reminder\Helper\SessionReminderHelper;

/**
 * Provides a Form for a modal form with a refresh button and countdown.
 */
class ModalForm extends FormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'sr__modal_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {

    if (!SessionReminderHelper::userEnabled()) {
      return $form;
    }

    $config = \Drupal::config('session_reminder.settings');
    $colorBtnBg = $config->get('color_btn_bg');
    $colorBtnText = $config->get('color_btn_text');
    $colorModalTitle = $config->get('color_modal_title');
    $colorModalBg = $config->get('color_modal_bg');
    $colorModalText = $config->get('color_modal_text');
    $modalBorderRadius = $config->get('modal_border_radius');

    $form['sr__modal_form']['cancel'] = [
      '#type' => 'markup',
      '#markup' => '<a class="sr--modal-form--cancel">X</a>',
    ];

    $form['sr__modal_form']['title'] = [
      '#type' => 'container',
      '#markup' => '<h2 class="sr--modal-form--title">' . $this->t('Session expiring') . '</h2>',
      '#attributes' => [
        'style' => "color: $colorModalTitle;",
      ],
    ];

    $form['sr__modal_form']['description'] = [
      '#type' => 'container',
      '#markup' => '<p class="sr--modal-form--description">' . $this->t("Your session will expire in @sec seconds", ['@sec' => 0]) . '</p>',
      '#attributes' => [
        'style' => "color: $colorModalText;",
      ],
    ];

    $form['sr__modal_form']['actions'] = ['#type' => 'actions'];

    $form['sr__modal_form']['actions']['submit'] = [
      '#type' => 'submit',
      '#button_type' => 'primary',
      '#value' => $this->t('Extend Session'),
      '#attributes' => [
        'class' => ['sr--modal-form--refresh-btn'],
        'style' => "background-color: $colorBtnBg; color: $colorBtnText;",
      ],
    ];

    $form['sr__modal_form']['actions']['close'] = [
      '#type' => 'button',
      '#button_type' => 'primary',
      '#value' => $this->t('Close'),
      '#attributes' => [
        'class' => ['sr--modal-form--close-btn'],
      ],
      '#submit' => ['::reloadPage'],
    ];

    $style = 'background-color: ' . $colorModalBg . ';';
    $style .= 'border-radius: ' . $modalBorderRadius . 'px;';
    $form['#attributes']['id'][] = 'sr--modal-form';
    $form['#attributes']['class'][] = 'sr--modal-form';
    $form['#attributes']['style'] = $style;
    $form['#cache'] = ['max-age' => 0];
    $form['#attached']['library'][] = 'session_reminder/modal-form-library';
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    // Chiamo servizio che estende sessione.
    $request = \Drupal::request();
    /** @var \Symfony\Component\HttpFoundation\Session\SessionInterface $session */
    $sessionCookieName = $request->getSession()->getName();

    if (SessionReminderHelper::userEnabled() && !empty($sessionCookieName) && isset($_COOKIE[$sessionCookieName])) {
      $sessionCookieValue = $_COOKIE[$sessionCookieName];
      unset($_COOKIE[$sessionCookieName]);
      $addSeconds = ini_get('session.cookie_lifetime');
      $newExpiringDatetime = time() + $addSeconds;
      setcookie(
        $sessionCookieName,
        $sessionCookieValue,
        $newExpiringDatetime,
        ini_get('session.cookie_path'),
        ini_get('session.cookie_domain'),
        ini_get('session.cookie_httponly'),
        ini_get('session.cookie_secure')
      );
      SessionHelper::setExpTimestamp($newExpiringDatetime);
    }
  }

  /**
   * Manage the reloadPage, used in Close Button.
   *
   * @param array $form
   *   An associative array containing the structure of the form.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   The current state of the form.
   *
   * @return void
   *   Redirect
   */
  public function reloadPage(array &$form, FormStateInterface $form_state) {
    // Refresh current page.
    $form_state->setRedirect('<current>');
  }

}
